package remoteMouse.controller;

import java.io.UnsupportedEncodingException;
import java.net.*;
import java.util.Calendar;
import java.util.Date;
import java.util.concurrent.locks.Lock;

import android.app.Activity;
import android.os.Bundle;
import android.util.Log;
import android.view.MotionEvent;
import android.view.View;

public class controller extends Activity {
    
	private DatagramPacket packet;
    private DatagramSocket socket;
    private float lastX;
    private float lastY;
    private float firstX;
    private float firstY;
    private Date clickDown;
    final int[] tolerance = {5,-5};
	
	@Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.main);
        
        try {
		this.socket = new DatagramSocket(8000);
		} catch(Throwable e) {
			e.printStackTrace();
		}
    }
    
    @Override
    public void onDestroy() {
    	this.socket.close();
    	super.onDestroy();
    }

    @Override
    public boolean onTouchEvent(MotionEvent event) {
    	super.onTouchEvent(event);
    	switch(event.getAction()) {
	    	case MotionEvent.ACTION_DOWN: {
	    		final float x = event.getX();
	    		final float y = event.getY();
	    		// last position
	    		this.lastX = x;
	    		this.lastY = y;
	    		// first position
	    		this.firstX = x;
	    		this.firstY = y;
	    		// click time
	    		this.clickDown = new Date();
	    		break;
	    	}
	    	case MotionEvent.ACTION_MOVE: {
	    		// new position
	    		final float x = event.getX();
	    		final float y = event.getY();
	    		
	    		//  get delta
	    		final float deltax = x - this.lastX;
	    		final float deltay = y - this.lastY;
	    		// set last position
	    		this.lastX = x;
	    		this.lastY = y;
	    			    		
				try {
					// prepare message -> x,y
					byte[] message = (deltax + "," + deltay).getBytes("UTF-8");
					// package definition. ip of pc and port.
					this.packet = new DatagramPacket(message, message.length, 
							InetAddress.getByName("192.168.0.150"), 8000);
					// send package
					this.socket.send(this.packet);
				} catch(Throwable e) {
					e.printStackTrace();
				}
	    		break;
	    	}
	    	
	    	case MotionEvent.ACTION_UP: {
	    		// get current position
	    		final float x = event.getX();
	    		final float y = event.getY();
	    		// get delta
	    		final float deltaX = this.firstX - x;
	    		final float deltaY = this.firstY - y;
	    		
	    		Date now = new Date();
	    		byte[] message = null;
	    		
	    		try {
	    			// when the users clicks and holds over 1 second send a double click to the pc.
		    		if (deltaX < this.tolerance[0] && 
	    				deltaX > this.tolerance[1] &&
	    				deltaY < this.tolerance[0] &&
	    				deltaY > this.tolerance[1] &&
	    				now.getTime() - this.clickDown.getTime() >= 1000) {
		    			message = ("d.click").getBytes("UTF-8");
	    			// When the users clicks (not holding) send a normal click to the pc.
		    		} else if (x == this.firstX && y == this.firstY) {
		    			message = ("click").getBytes("UTF-8");
		    		}
		    		if (message != null) {
		    			// prepare and send package -> d.click or click
		    			this.packet = new DatagramPacket(message, message.length, InetAddress.getByName("192.168.0.150"), 8000);
						this.socket.send(this.packet);	
		    		}
				} catch (Throwable e) {
					e.printStackTrace();
	    		}
	    		break;
	    	}
    	}
    	return true;
    }
}